IntRange

Struct IntRange 

pub struct IntRange {
    pub lo: MaybeInfiniteInt,
    pub hi: MaybeInfiniteInt,
}
An exclusive interval, used for precise integer exhaustiveness checking. IntRanges always store a contiguous range.

IntRange is never used to encode an empty range or a “range” that wraps around the (offset) space: i.e., range.lo < range.hi.

Fields

lo: MaybeInfiniteInthi: MaybeInfiniteInt

Implementations

Source

impl IntRange

pub fn is_singleton(&self) -> bool

Best effort; will not know that e.g. 255u8.. is a singleton.

pub fn from_singleton(x: MaybeInfiniteInt) -> IntRange

Construct a singleton range. x must be a Finite(_) value.

pub fn from_range( lo: MaybeInfiniteInt, hi: MaybeInfiniteInt, end: RangeEnd, ) -> IntRange

Construct a range with these boundaries. lo must not be PosInfinity. hi must not be NegInfinity.

pub fn is_subrange(&self, other: &Self) -> bool