pub enum Usefulness<'p, Cx: PatCx> {
Useful(Vec<(&'p DeconstructedPat<Cx>, RedundancyExplanation<'p, Cx>)>),
Redundant(RedundancyExplanation<'p, Cx>),
}Expand description
Indicates whether or not a given arm is useful.
Variants
Useful(Vec<(&'p DeconstructedPat<Cx>, RedundancyExplanation<'p, Cx>)>)
The arm is useful. This additionally carries a set of or-pattern branches that have been found to be redundant despite the overall arm being useful. Used only in the presence of or-patterns, otherwise it stays empty.
Redundant(RedundancyExplanation<'p, Cx>)
The arm is redundant and can be removed without changing the behavior of the match expression.