pub struct RedundancyExplanation<'p, Cx: PatCx> {
pub covered_by: Vec<&'p DeconstructedPat<Cx>>,
}Expand description
Indicates why a given pattern is considered redundant.
Fields
covered_by: Vec<&'p DeconstructedPat<Cx>>All the values matched by this pattern are already matched by the given set of patterns. This list is not guaranteed to be minimal but the contained patterns are at least guaranteed to intersect this pattern.