UsefulnessReport

Struct UsefulnessReport 

pub struct UsefulnessReport<'p, Cx: PatCx> {
    pub arm_usefulness: Vec<(MatchArm<'p, Cx>, Usefulness<'p, Cx>)>,
    pub non_exhaustiveness_witnesses: Vec<WitnessPat<Cx>>,
    pub arm_intersections: Vec<DenseBitSet<usize>>,
}
The output of checking a match for exhaustiveness and arm usefulness.

Fields

arm_usefulness: Vec<(MatchArm<'p, Cx>, Usefulness<'p, Cx>)>

For each arm of the input, whether that arm is useful after the arms above it.

non_exhaustiveness_witnesses: Vec<WitnessPat<Cx>>

If the match is exhaustive, this is empty. If not, this contains witnesses for the lack of exhaustiveness.

arm_intersections: Vec<DenseBitSet<usize>>

For each arm, a set of indices of arms above it that have non-empty intersection, i.e. there is a value matched by both arms. This may miss real intersections.